package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.OperationRecord;

/**
 * 操作记录Service接口
 * 
 * @author boman
 * @date 2025-05-16
 */
public interface IOperationRecordService 
{
    /**
     * 查询操作记录
     * 
     * @param id 操作记录主键
     * @return 操作记录
     */
    public OperationRecord selectOperationRecordById(Long id);

    /**
     * 查询操作记录列表
     * 
     * @param operationRecord 操作记录
     * @return 操作记录集合
     */
    public List<OperationRecord> selectOperationRecordList(OperationRecord operationRecord);

    /**
     * 新增操作记录
     * 
     * @param operationRecord 操作记录
     * @return 结果
     */
    public int insertOperationRecord(OperationRecord operationRecord);

    /**
     * 修改操作记录
     * 
     * @param operationRecord 操作记录
     * @return 结果
     */
    public int updateOperationRecord(OperationRecord operationRecord);

    /**
     * 批量删除操作记录
     * 
     * @param ids 需要删除的操作记录主键集合
     * @return 结果
     */
    public int deleteOperationRecordByIds(Long[] ids);

    /**
     * 删除操作记录信息
     * 
     * @param id 操作记录主键
     * @return 结果
     */
    public int deleteOperationRecordById(Long id);
}
